==> tblock-2.0.0.tar.gz: tblock-2.0.0/.gitea/issue_template/bug_report.md <==
---

name: "Bug Report"
about: "Report a bug in the software"
title: "[BUG] A clear title"
labels:
- bug

---

**Before opening:**

<!-- 
Please check this before opening a new issue
-->

- [ ] This issue is not duplicated

---

**Platform and software version:**

- I am running TBlock version: `version`
- My local version of the filter list repository is: `version`
- Check the platform you are running:
  - [ ] GNU/Linux, Linux
  - [ ] Android (using Termux)
  - [ ] macOS
  - [ ] Microsoft Windows
  - [ ] *BSD
  - [ ] Other: `please specify here`
- Check the installation method you used to install TBlock:
  - [ ] Python Index Package (pip)
  - [ ] AUR
  - [ ] Fedora COPR
  - [ ] Ubuntu PPA
  - [ ] Homebrew
  - [ ] Scoop
  - [ ] Windows installer (EXE file)
  - [ ] Makefile (using the latest release)
  - [ ] Makefile (using the `main` branch)
  - [ ] Other: `please specify here`

---

**Error code:**

- The bug results in a non-zero error code: `y/n`

<!-- 
If the bug results in a non-zero error code, please copy/paste the console output below.
-->

Console output:

```

```

---

**Describe the issue:**

<!-- 
Insert a clear and concise description below
-->



---


**Steps to reproduce:**

- This issue is possible to reproduce: `y/n`

<!-- 
If it is reproducible, enter the steps to reproduce it below
-->

1. Do something
2. Do something else
3. See error

---

**Logs:**

<!-- 
If you want, you can attach TBlock's log file for more information.
This is not required, but it can be useful for some bugs. Delete this section if you don't want to provide your log file.

Under UNIX-like systems, you can find the log file under:
-> /var/log/tblock.log

Under Android with Termux, you can find the log file under:
-> /data/data/com.termux/files/usr/var/log/tblock.log

Under Windows, you can find the log file under:
-> %ALLUSERSPROFILE%\TBlock\tblock.log
-->

---

**More details:**

<!--
If you want, you can specify some other details here. Otherwise, delete this section.
-->

==> tblock-2.1.0.tar.gz: tblock-2.1.0/.gitea/issue_template/bug_report.md <==
---

name: "Bug Report"
about: "Report a bug in the software"
title: "[BUG] A clear title"
labels:
- bug

---

**Before opening:**

<!-- 
Please check this before opening a new issue
-->

- [ ] This issue is not duplicated

---

**Platform and software version:**

- I am running TBlock version: `version`
- My local version of the filter list repository is: `version`
- Check the platform you are running:
  - [ ] GNU/Linux, Linux
  - [ ] Android (using Termux)
  - [ ] macOS
  - [ ] Microsoft Windows
  - [ ] *BSD
  - [ ] Other: `please specify here`
- Check the installation method you used to install TBlock:
  - [ ] Python Index Package (pip)
  - [ ] AUR
  - [ ] Fedora COPR
  - [ ] Ubuntu PPA
  - [ ] Homebrew
  - [ ] Scoop
  - [ ] Windows installer (EXE file)
  - [ ] Makefile (using the latest release)
  - [ ] Makefile (using the `main` branch)
  - [ ] Other: `please specify here`

---

**Filter lists:**

<!--
Please enter the filter lists you subscribe to (list them with "tblock -Lk")
-->

```

```

**Error code:**

- The bug results in a non-zero error code: `y/n`

<!-- 
If the bug results in a non-zero error code, please copy/paste the console output below.
-->

Console output:

```

```

---

**Describe the issue:**

<!-- 
Insert a clear and concise description below
-->



---


**Steps to reproduce:**

- This issue is reproducible: `y/n`

<!-- 
If it is reproducible, enter the steps to reproduce it below
-->

1. Do something
2. Do something else
3. See error

---

**Logs:**

<!-- 
If you want, you can attach TBlock's log file for more information.
This is not required, but it can be useful for some bugs. Delete this section if you don't want to provide your log file.

Under UNIX-like systems, you can find the log file under:
-> /var/log/tblock.log

Under Android with Termux, you can find the log file under:
-> /data/data/com.termux/files/usr/var/log/tblock.log

Under Windows, you can find the log file under:
-> %ALLUSERSPROFILE%\TBlock\tblock.log
-->

---

**More details:**

<!--
If you want, you can specify some other details here. Otherwise, delete this section.
-->
